@@ -66,21 +66,23 @@ def get_name(executable) -> str:
 
 def init() -> None:
     """Basic initialization of the startup script."""
-    # to avoid bugs (especially in MSYS2) use normpath after any change
-    sys.executable = os.path.normpath(sys.executable)
-    sys.frozen_dir = frozen_dir = os.path.dirname(sys.executable)
-    sys.meta_path.append(ExtensionFinder)
+    # fix prefix if using console_legacy
+    if not sys.prefix:
+        sys.prefix = os.path.dirname(sys.executable)
+        sys.base_prefix = sys.base_exec_prefix = sys.exec_prefix = sys.prefix
 
-    # normalize and check sys.path, preserving the reference
-    j = 0
-    for path in list(map(os.path.normpath, sys.path)):
-        if os.path.exists(path):
-            sys.path[j] = path
-            j = j + 1
-        else:
-            sys.path.remove(path)
+    # enable ExtensionFinder only if uses a zip file
+    for path in sys.path:
+        if path.endswith(".zip"):
+            sys.meta_path.append(ExtensionFinder)
+            break
 
     if sys.platform.startswith("win"):
+        # to avoid bugs, especially in MSYS2, normalize sys.argv and sys.path
+        # (preserving the reference)
+        for j, path in enumerate(sys.path):
+            sys.path[j] = os.path.normpath(path)
+        sys.argv[0] = os.path.normpath(sys.argv[0])
         # the search path for dependencies
         search_path: list[str] = [
             entry for entry in sys.path if os.path.isdir(entry)
@@ -97,27 +99,6 @@ def init() -> None:
         env_path = [entry.replace(os.sep, "\\") for entry in env_path]
         os.environ["PATH"] = os.pathsep.join(env_path)
 
-    # set environment variables
-    for name in (
-        "TCL_LIBRARY",
-        "TK_LIBRARY",
-        "PYTHONTZPATH",
-    ):
-        try:
-            value = getattr(BUILD_CONSTANTS, name)
-        except AttributeError:
-            pass
-        else:
-            var_path = os.path.join(frozen_dir, os.path.normpath(value))
-            if not os.path.exists(var_path) and sys.platform == "darwin":
-                # when using bdist_mac
-                var_path = os.path.join(
-                    os.path.dirname(frozen_dir),
-                    "Resources",
-                    os.path.normpath(value),
-                )
-            os.environ[name] = var_path
-
 
 def run() -> None:
     """Determines the name of the initscript and execute it."""
