@@ -1,6 +1,4 @@
-"""
-A setup script to create executables and demonstrate the use pythonnet.
-"""
+"""A setup script to create executables and demonstrate the use pythonnet."""
 
 from cx_Freeze import Executable, setup
 
